==> calamares-settings-solydxk_4.17%2Br13.tar.xz: source/ts/calamares-solydxk_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Gràcies per triar SolydXK&lt;/h3&gt;&lt;br /&gt;Heu triat una distribució que és:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura i estable&lt;/li&gt;&lt;li&gt;Ràpida i efectiva&lt;/li&gt;&lt;li&gt;A punt per l&apos;escriptori&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Gaudiu d&apos;aquesta nova edició.&lt;br /&gt;&lt;br /&gt;La instal·lació triga entre 15 i 30 minuts, depenent del vostre maquinari.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Sobre les espatlles de Gegants&lt;/h3&gt;&lt;br /&gt;SolydXK és una distribució GNU/Linux basada en Debian i compatible amb aquesta.&lt;br /&gt;&lt;br /&gt;SolydXK usa l&apos;escriptori lleuger Xfce per a SolydX o bé l&apos;escriptori KDE per a SolydK, molt configurable i atractiu.&lt;br /&gt;&lt;br /&gt;Les nostres innovacions i la gran selecció de paquets de Debian fan de Linux SolydXK un dels sistemes operatius d&apos;escriptori més atractius disponible per als usuaris domèstics.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;A punt per a usar-la&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird i LibreOffice venen preinstal·lats a SolydXK, de manera que podeu començar immediatament a utilitzar internet i l&apos;escriptori.&lt;br /&gt;&lt;br /&gt;A diferència d&apos;altres distribucions Linux, SolydXK està preparada per reproduir la vostra música, vídeos d&apos;internet i més.&lt;br /&gt;&lt;br /&gt;Amb un clic del ratolí, podeu instal·lar una àmplia varietat de programari.&lt;br /&gt;&lt;br /&gt;SolydXK és compatible amb els formats de fitxer més populars: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, i molts més.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Eines d&apos;oficina a punt d&apos;usar així que instal·leu SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice,  un potent paquet ofimàtic, ja ve incorporat a SolydXK d&apos;origen.&lt;br /&gt;&lt;br /&gt;LibreOffice és molt fàcil d&apos;aprendre i utilitzar.&lt;br /&gt;&lt;br /&gt;Podeu usar-lo per editar cartes, presentacions i fulls de càlcul, així com diagrames i bases de dades.&lt;br /&gt;&lt;br /&gt;LibreOffice usa el format estàndard OpenDocument i és compatible amb els documents d&apos;altres paquets ofimàtics, tals com WordPerfect i Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Una alternativa als Sistemes Operatius més coneguts&lt;/h3&gt;&lt;br /&gt;SolydXK és fàcil d&apos;usar, potent i configurable.&lt;br /&gt;&lt;br /&gt;SolydXK és segur i estable. A diferència d&apos;altres Sistemes Operatius, no és procliu a virus ni programes espia, no pateix fragmentació de disc ni té un Registre que necessiti neteges periòdiques.&lt;br /&gt;&lt;br /&gt;SolydXK pot detectar altres Sistemes Operatius i instal·lar-se juntament amb ells. Podeu triar també quin Sistema Operatiu s&apos;executarà en iniciar l&apos;equip.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualitzacions segures&lt;/h3&gt;&lt;br /&gt;Alguns Sistemes Operatius fan que l&apos;actualització del vostre sistema sigui més complicat del que caldria. SolydXK creu que les actualitzacions han de ser ràpides i fàcils, i no destorbar un cop fetes.&lt;br /&gt;&lt;br /&gt;El Gestor d&apos;actualitzacions roman discretament a la safata de sistema i us avisarà quan hi hagi actualitzacions disponibles. No cal que apliqueu les actualitzacions si no ho voleu. El Gestor d&apos;actualitzacions no mostrarà finestres emergents ni molestarà de cap altra manera.&lt;br /&gt;&lt;br /&gt;Tots els fitxers tenen el manteniment i la revisió acurada de desenvolupadors i mantenidors de confiança.&lt;br /&gt;&lt;br /&gt;Tots els fitxers es desen en dipòsits segurs, especials per al vostre ús.&lt;br /&gt;&lt;br /&gt;El dipòsit de seguretat se sincronitza diàriament.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Una gran comunitat&lt;/h3&gt;&lt;br /&gt;Els usuaris de SolydXK gaudeixen en compartir la seva passió i entusiasme i estan disposats a ajudar. No dubteu a fer preguntes als fòrums o a involucrar-vos amb la comunitat.&lt;br /&gt;&lt;br /&gt;Envieu-nos comentaris i expliqueu-nos la vostra experiència. Escoltarem les vostres idees i les usarem per a millorar SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Gràcies per triar SolydXK&lt;/h3&gt;&lt;br /&gt;Heu triat una distribució que és:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura i estable&lt;/li&gt;&lt;li&gt;Ràpida i efectiva&lt;/li&gt;&lt;li&gt;A punt per l&apos;escriptori&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Gaudiu d&apos;aquesta nova edició.&lt;br /&gt;&lt;br /&gt;La instal·lació triga entre 15 i 30 minuts, depenent del vostre maquinari.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Sobre les espatlles de Gegants&lt;/h3&gt;&lt;br /&gt;SolydXK és una distribució GNU/Linux basada en Debian i compatible amb aquesta.&lt;br /&gt;&lt;br /&gt;SolydXK usa l&apos;escriptori lleuger Xfce per a SolydX o bé l&apos;escriptori KDE per a SolydK, molt configurable i atractiu.&lt;br /&gt;&lt;br /&gt;Les nostres innovacions i la gran selecció de paquets de Debian fan de Linux SolydXK un dels sistemes operatius d&apos;escriptori més atractius disponible per als usuaris domèstics.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;A punt per a usar-la&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird i LibreOffice venen preinstal·lats a SolydXK, de manera que podeu començar immediatament a utilitzar internet i l&apos;escriptori.&lt;br /&gt;&lt;br /&gt;A diferència d&apos;altres distribucions Linux, SolydXK està preparada per reproduir la vostra música, vídeos d&apos;internet i més.&lt;br /&gt;&lt;br /&gt;Amb un clic del ratolí, podeu instal·lar una àmplia varietat de programari.&lt;br /&gt;&lt;br /&gt;SolydXK és compatible amb els formats de fitxer més populars: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, i molts més.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Eines d&apos;oficina a punt d&apos;usar així que instal·leu SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice,  un potent paquet ofimàtic, ja ve incorporat a SolydXK d&apos;origen.&lt;br /&gt;&lt;br /&gt;LibreOffice és molt fàcil d&apos;aprendre i utilitzar.&lt;br /&gt;&lt;br /&gt;Podeu usar-lo per editar cartes, presentacions i fulls de càlcul, així com diagrames i bases de dades.&lt;br /&gt;&lt;br /&gt;LibreOffice usa el format estàndard OpenDocument i és compatible amb els documents d&apos;altres paquets ofimàtics, tals com WordPerfect i Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Una alternativa als Sistemes Operatius més coneguts&lt;/h3&gt;&lt;br /&gt;SolydXK és fàcil d&apos;usar, potent i configurable.&lt;br /&gt;&lt;br /&gt;SolydXK és segur i estable. A diferència d&apos;altres Sistemes Operatius, no és procliu a virus ni programes espia, no pateix fragmentació de disc ni té un Registre que necessiti neteges periòdiques.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualitzacions segures&lt;/h3&gt;&lt;br /&gt;Alguns Sistemes Operatius fan que l&apos;actualització del vostre sistema sigui més complicat del que caldria. SolydXK creu que les actualitzacions han de ser ràpides i fàcils, i no destorbar un cop fetes.&lt;br /&gt;&lt;br /&gt;El Gestor d&apos;actualitzacions roman discretament a la safata de sistema i us avisarà quan hi hagi actualitzacions disponibles. No cal que apliqueu les actualitzacions si no ho voleu. El Gestor d&apos;actualitzacions no mostrarà finestres emergents ni molestarà de cap altra manera.&lt;br /&gt;&lt;br /&gt;Tots els fitxers tenen el manteniment i la revisió acurada de desenvolupadors i mantenidors de confiança.&lt;br /&gt;&lt;br /&gt;Tots els fitxers es desen en dipòsits segurs, especials per al vostre ús.&lt;br /&gt;&lt;br /&gt;El dipòsit de seguretat se sincronitza diàriament.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Una gran comunitat&lt;/h3&gt;&lt;br /&gt;Els usuaris de SolydXK gaudeixen en compartir la seva passió i entusiasme i estan disposats a ajudar. No dubteu a fer preguntes als fòrums o a involucrar-vos amb la comunitat.&lt;br /&gt;&lt;br /&gt;Envieu-nos comentaris i expliqueu-nos la vostra experiència. Escoltarem les vostres idees i les usarem per a millorar SolydXK.</translation>
    </message>
</context>
</TS>
